NegFOperation

Struct NegFOperation 

pub struct NegFOperation<'c> { /* private fields */ }
A negf operation. Floating point negation.

The negf operation computes the negation of a given value. It takes one operand and returns one result of the same type. This type may be a float scalar type, a vector whose element type is float, or a tensor of floats. It has no standard attributes.

Example:

// Scalar negation value.
%a = arith.negf %b : f64

// SIMD vector element-wise negation value.
%f = arith.negf %g : vector<4xf32>

// Tensor element-wise negation value.
%x = arith.negf %y : tensor<4x?xf8>

Implementations

Source

impl<'c> NegFOperation<'c>

pub fn name() -> &'static str

Returns a name.

pub fn as_operation(&self) -> &Operation<'c>

Returns a generic operation.

pub fn builder( context: &'c Context, location: Location<'c>, ) -> NegFOperationBuilder<'c, Unset>

Creates a builder.

pub fn result(&self) -> Result<OperationResult<'c, '_>, Error>

pub fn operand(&self) -> Result<Value<'c, '_>, Error>

pub fn fastmath(&self) -> Result<Attribute<'c>, Error>

pub fn set_fastmath(&mut self, value: Attribute<'c>)

pub fn remove_fastmath(&mut self) -> Result<(), Error>