ShRSIOperation

Struct ShRSIOperation 

pub struct ShRSIOperation<'c> { /* private fields */ }
A shrsi operation. Signed integer right-shift.

The shrsi operation shifts an integer value of the first operand to the right by the value of the second operand. The first operand is interpreted as signed, and the second operand is interpreter as unsigned. The high order bits in the output are filled with copies of the most-significant bit of the shifted value (which means that the sign of the value is preserved). If the value of the second operand is greater or equal than bitwidth of the first operand, then the operation returns poison.

If the exact attribute is present, the result value of shrsi is a poison value if any of the bits shifted out are non-zero.

Example:

%1 = arith.constant 160 : i8         // %1 is 0b10100000
%2 = arith.constant 3 : i8
%3 = arith.shrsi %1, %2 exact : i8   // %3 is 0b11110100
%4 = arith.constant 98 : i8          // %4 is 0b01100010
%5 = arith.shrsi %4, %2 : i8         // %5 is 0b00001100

Implementations

Source

impl<'c> ShRSIOperation<'c>

pub fn name() -> &'static str

Returns a name.

pub fn as_operation(&self) -> &Operation<'c>

Returns a generic operation.

pub fn builder( context: &'c Context, location: Location<'c>, ) -> ShRSIOperationBuilder<'c, Unset, Unset>

Creates a builder.

pub fn result(&self) -> Result<OperationResult<'c, '_>, Error>

pub fn lhs(&self) -> Result<Value<'c, '_>, Error>

pub fn rhs(&self) -> Result<Value<'c, '_>, Error>

pub fn is_exact(&self) -> Result<Attribute<'c>, Error>

pub fn set_is_exact(&mut self, value: Attribute<'c>)

pub fn remove_is_exact(&mut self) -> Result<(), Error>