pub struct DivSIOperation<'c> { /* private fields */ }Expand description
A divsi operation. Signed integer division operation.
Signed integer division. Rounds towards zero. Treats the leading bit as
sign, i.e. 6 / -2 = -3.
Divison by zero, or signed division overflow (minimum value divided by -1)
is undefined behavior. When applied to vector and tensor values, the
behavior is undefined if any of its elements are divided by zero or has a
signed division overflow.
If the exact attribute is present, the result value is poison if lhs is
not a multiple of rhs.
Example:
// Scalar signed integer division.
%a = arith.divsi %b, %c : i64
// Scalar signed integer division where %b is known to be a multiple of %c.
%a = arith.divsi %b, %c exact : i64
// SIMD vector element-wise division.
%f = arith.divsi %g, %h : vector<4xi32>
// Tensor element-wise integer division.
%x = arith.divsi %y, %z : tensor<4x?xi8>Implementations
Sourceimpl<'c> DivSIOperation<'c>
impl<'c> DivSIOperation<'c>
Sourcepub fn as_operation(&self) -> &Operation<'c>
pub fn as_operation(&self) -> &Operation<'c>
Returns a generic operation.
Sourcepub fn builder(
context: &'c Context,
location: Location<'c>,
) -> DivSIOperationBuilder<'c, Unset, Unset>
pub fn builder( context: &'c Context, location: Location<'c>, ) -> DivSIOperationBuilder<'c, Unset, Unset>
Creates a builder.
pub fn result(&self) -> Result<OperationResult<'c, '_>, Error>
pub fn lhs(&self) -> Result<Value<'c, '_>, Error>
pub fn rhs(&self) -> Result<Value<'c, '_>, Error>
pub fn is_exact(&self) -> Result<Attribute<'c>, Error>
pub fn set_is_exact(&mut self, value: Attribute<'c>)
pub fn remove_is_exact(&mut self) -> Result<(), Error>